aboutsummaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
Diffstat (limited to 'sys')
-rw-r--r--sys/dev/ath/if_ath.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/sys/dev/ath/if_ath.c b/sys/dev/ath/if_ath.c
index 2841e8e473ae..2e85aec9f176 100644
--- a/sys/dev/ath/if_ath.c
+++ b/sys/dev/ath/if_ath.c
@@ -4798,8 +4798,10 @@ ath_tx_draintxq(struct ath_softc *sc, struct ath_txq *txq)
bf->bf_node = NULL;
if (ni != NULL) {
/*
* Reclaim node reference.
*/
+ if (bf->bf_m->m_flags & M_TXCB)
+ ieee80211_process_callback(ni, bf->bf_m, -1);
ieee80211_free_node(ni);
}
m_freem(bf->bf_m);
@@ -4798,8 +4798,10 @@ ath_tx_draintxq(struct ath_softc *sc, struct ath_txq *txq)
if (ni != NULL) {
/*
- * Reclaim node reference.
+ * Do any callback and reclaim the node reference.
*/